==> react-native-hotqa-sdk-0.2.1.tgz: package/src/components/writing/index.js <==
import React from 'react';
import {StyleSheet, View, TextInput, Dimensions, Text} from 'react-native';
import {onConfigurations} from '../../common/helper';

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const {configurations} = item;
  const {correct_answer} = JSON.parse(configurations);
  let answerInput = null;

  if (isFinish && user_answer) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        answerInput = answer.user_answer.value;
      }
    });
  }

  return (
    <View style={[styles.configView]}>
      <TextInput
        editable={isFinish ? false : true}
        autoFocus={false}
        placeholder="Type here..."
        style={styles.textInput}
        multiline={true}
        underlineColorAndroid="transparent"
        onChangeText={(text) => {
          onConfigurations(item, text, dispatch);
          audio();
        }}
        autoCapitalize="none"
        returnKeyType="done"
        value={answerInput && answerInput}
      />
      {isFinish && (
        <Text style={styles.textAnswer}>Đáp án: {'\n' + correct_answer}</Text>
      )}
    </View>
  );
};

const width = Dimensions.get('screen').width * 0.5;
const styles = StyleSheet.create({
  configView: {
    width: width,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textInput: {
    width: width,
    color: 'black',
    fontSize: 18,
    minHeight: 100,
    lineHeight: 26,
    // minHeight: 50,
    // borderColor: 'gray',
    // borderWidth: 1,
    backgroundColor: '#F0F4F9',
    borderRadius: 10,
    padding: 16,
  },
  textAnswer: {
    color: 'red',
    fontSize: 18,
    lineHeight: 28,
    marginTop: 50,
  },
});

==> react-native-hotqa-sdk-0.2.2.tgz: package/src/components/writing/index.js <==
import React from 'react';
import {StyleSheet, View, TextInput, Dimensions, Text} from 'react-native';
import {onConfigurations} from '../../common/helper';

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const {configurations} = item;
  const {correct_answer} = JSON.parse(configurations);
  let answerInput = null;

  if (isFinish && user_answer) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        answerInput = answer.user_answer.value;
      }
    });
  }

  const showAnswer = () => {
    let answer = '';
    correct_answer.forEach((a, i) => {
      if (i === 0) {
        answer = a;
      } else {
        answer = answer + ' / ' + a;
      }
    });
    return answer;
  };

  return (
    <View style={[styles.configView]}>
      <TextInput
        editable={isFinish ? false : true}
        autoFocus={false}
        placeholder="Type here..."
        style={styles.textInput}
        multiline={true}
        underlineColorAndroid="transparent"
        onChangeText={(text) => {
          onConfigurations(item, text, dispatch);
          audio();
        }}
        autoCapitalize="none"
        returnKeyType="done"
        value={answerInput && answerInput}
      />
      {isFinish && (
        <Text style={styles.textAnswer}>Đáp án: {'\n' + showAnswer()}</Text>
      )}
    </View>
  );
};

const width = Dimensions.get('screen').width * 0.5;
const styles = StyleSheet.create({
  configView: {
    width: width,
    justifyContent: 'center',
    alignItems: 'center',
  },
  textInput: {
    width: width,
    color: 'black',
    fontSize: 18,
    minHeight: 100,
    lineHeight: 26,
    // minHeight: 50,
    // borderColor: 'gray',
    // borderWidth: 1,
    backgroundColor: '#F0F4F9',
    borderRadius: 10,
    padding: 16,
  },
  textAnswer: {
    color: 'red',
    fontSize: 18,
    lineHeight: 28,
    marginTop: 50,
  },
});
